# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["DatasetUploadFileResponse", "S3PresignedPost"]


class S3PresignedPost(BaseModel):
    fields: Dict[str, str]
    """Fields required for the S3 presigned POST request generated by s3 sdk."""

    url: str


class DatasetUploadFileResponse(BaseModel):
    s3_presigned_post: S3PresignedPost = FieldInfo(alias="s3PresignedPost")
