# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .._models import BaseModel

__all__ = ["EvaluationDeleteRunResponse"]


class EvaluationDeleteRunResponse(BaseModel):
    id: str
    """The ID of the deleted evaluation run"""
